!function(){"use strict";Array.prototype.includes||(Array.prototype.includes=function(e){if(null==this)throw new TypeError("Array.prototype.includes called on null or undefined");var t=Object(this),r=parseInt(t.length,10)||0;if(0===r)return!1;var n,o,s=parseInt(arguments[1],10)||0;for(0<=s?n=s:(n=r+s)<0&&(n=0);n<r;){if(e===(o=t[n])||e!=e&&o!=o)return!0;n++}return!1});var e="function"==typeof fetch?fetch.bind():function(o,s){return s=s||{},new Promise(function(e,t){var r=new XMLHttpRequest;for(var n in r.open(s.method||"get",o),s.headers)r.setRequestHeader(n,s.headers[n]);function i(){var n,o=[],s=[],u={};return r.getAllResponseHeaders().replace(/^(.*?):\s*([\s\S]*?)$/gm,function(e,t,r){o.push(t=t.toLowerCase()),s.push([t,r]),n=u[t],u[t]=n?n+","+r:r}),{ok:1==(r.status/200|0),status:r.status,statusText:r.statusText,url:r.responseURL,clone:i,text:function(){return Promise.resolve(r.responseText)},json:function(){return Promise.resolve(r.responseText).then(JSON.parse)},blob:function(){return Promise.resolve(new Blob([r.response]))},headers:{keys:function(){return o},entries:function(){return s},get:function(e){return u[e.toLowerCase()]},has:function(e){return e.toLowerCase()in u}}}}r.withCredentials="include"==s.credentials,r.onload=function(){e(i())},r.onerror=t,r.send(s.body)})},t=Object.freeze({default:e}),r=t&&e||t;function n(e,t){if(null==e)throw new TypeError("Cannot convert first argument to object");for(var r=Object(e),n=1;n<arguments.length;n++){var o=arguments[n];if(null!=o)for(var s=Object.keys(Object(o)),u=0,i=s.length;u<i;u++){var a=s[u],c=Object.getOwnPropertyDescriptor(o,a);void 0!==c&&c.enumerable&&(r[a]=o[a])}}return r}window.fetch||(window.fetch=r.default||r),{assign:n,polyfill:function(){Object.assign||Object.defineProperty(Object,"assign",{enumerable:!1,configurable:!0,writable:!0,value:n})}}.polyfill(),void 0===Object.values&&(Object.values=function(t){return Object.keys(t).map(function(e){return t[e]})})}();